'use strict';

const {log, clearNulls} = require('../../../core/utils');
const {BanRecord, ValidationError} = require('../../../models');

module.exports = async (req, res) => {
    if (!req.user.roles.intBanRecordsWriter) {
        res.status(403).send({status: 'Unauthorized'});
        return;
    }

    const payload = req.body;
    log('Creating int ban record', {payload, user: req.user});

    try {
        const record = await BanRecord
            .query()
            .insert(clearNulls({
                addedBy: req.user.id,
                accusedDiscordId: payload.accusedDiscordId,
                accusedDiscordUsername: payload.accusedDiscordUsername || null,
                caseOrigin: payload.caseOrigin,
                caseModerator: payload.caseModerator || null,
                caseDescription: payload.caseDescription || null,
                bannedUntil: payload.bannedUntil || null
            }))
            .returning('*');

        res.send({
            status: 'ok',
            record
        });
    } catch (error) {
        if (error instanceof ValidationError) {
            res.status(400).send({
                error: 'Validation failed',
                details: error.data
            });
        } else {
            res.status(500).send({error: 'Internal server error'});
        }
        console.error('Error creating a record', error);
    }
};
